============
WikiDataSets
============

.. image:: https://img.shields.io/pypi/v/wikidatasets.svg
        :target: https://pypi.python.org/pypi/wikidatasets

.. image:: https://img.shields.io/travis/armand33/wikidatasets.svg
        :target: https://travis-ci.org/armand33/wikidatasets

.. image:: https://readthedocs.org/projects/wikidatasets/badge/?version=latest
        :target: https://wikidatasets.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/armand33/wikidatasets/shield.svg
     :target: https://pyup.io/repos/github/armand33/wikidatasets/
     :alt: Updates

Breaking WikiData dumps into smaller knowledge graphs (e.g. graph of human entities).


* Free software: BSD license
* Documentation: https://wikidatasets.readthedocs.io.
* Paper: https://arxiv.org/abs/1906.04536
* Dataset downloads: `here <https://graphs.telecom-paristech.fr/Home_page.html#wikidatasets-section>`_

Citations
---------
If you find this code useful in your research, please consider citing our `paper <https://arxiv.org/abs/1906.04536>`_:

.. code-block::

    @article{boschin_wikidatasets_2019,
        title = {{WikiDataSets}: {Standardized} sub-graphs from {Wikidata}},
        shorttitle = {{WikiDataSets}},
        url = {http://arxiv.org/abs/1906.04536},
        journal = {arXiv:1906.04536 [cs, stat]},
        author = {Boschin, Armand and Bonald, Thomas},
        month = oct,
        year = {2019},
        note = {arXiv: 1906.04536},
        keywords = {Computer Science - Artificial Intelligence, Computer Science - Machine Learning, Computer Science - Social and Information Networks, Statistics - Machine Learning}
    }
